Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Base implementation for all JavaScript SDK clients.
 *
 * Call the constructor with the options specific to the client subclass.
 * To access these options later, use {@link Client.getOptions}.
 *
 * @example
 * class NodeClient extends BaseClient<NodeOptions> {
 *   public constructor(apiKey: String, options: NodeOptions) {
 *   }
 *
 *   // ...
 * }
 */
var BaseClient = /** @class */ (function () {
    /**
     * Initializes this client instance.
     *
     * @param apiKey API key for your project
     * @param options options for the client
     */
    function BaseClient(apiKey, options) {
        this._apiKey = apiKey;
        this._options = options;
    }
    /**
     * @inheritDoc
     */
    BaseClient.prototype.getOptions = function () {
        return this._options;
    };
    /**
     * @inheritDoc
     */
    BaseClient.prototype.logEvent = function (event) {
        throw new Error("Method not implemented. Event: " + JSON.stringify(event));
    };
    /**
     * @inheritDoc
     */
    BaseClient.prototype.flush = function () {
        throw new Error('Method not implemented.');
    };
    return BaseClient;
}());
exports.BaseClient = BaseClient;
//# sourceMappingURL=baseClient.js.map