import { Client } from '../models/client';
import { Event } from '../models/event';
import { Options } from '../models/options';
/**
 * Base implementation for all JavaScript SDK clients.
 *
 * Call the constructor with the options specific to the client subclass.
 * To access these options later, use {@link Client.getOptions}.
 *
 * @example
 * class NodeClient extends BaseClient<NodeOptions> {
 *   public constructor(apiKey: String, options: NodeOptions) {
 *   }
 *
 *   // ...
 * }
 */
export declare abstract class BaseClient<O extends Options> implements Client<O> {
    /** Project Api Key */
    protected readonly _apiKey: string;
    /** Options for the client. */
    protected readonly _options: O;
    /**
     * Initializes this client instance.
     *
     * @param apiKey API key for your project
     * @param options options for the client
     */
    constructor(apiKey: string, options: O);
    /**
     * @inheritDoc
     */
    getOptions(): O;
    /**
     * @inheritDoc
     */
    logEvent(event: Event): void;
    /**
     * @inheritDoc
     */
    flush(): void;
}
//# sourceMappingURL=baseClient.d.ts.map